@@ -33,26 +33,44 @@ class TestTemplates(unittest.TestCase):
 
     def test_category(self):
         categories = ['python sdk test']
-        self.templates.category(test_org, self.template_id, self.template_name, self.version, categories)
+        self.templates.category(
+            org_id=test_org,
+            template_id=self.template_id,
+            template_name=self.template_name,
+            version=self.version,
+            categories=categories
+        )
 
-        all_categories = self.templates.list_all_categories(test_org)
+        all_categories = self.templates.list_all_categories(org_id=test_org)
         self.assertListEqual(list(all_categories.keys()), categories)
-        
-        template_category_ids  =  self.templates.get_template(test_org, self.template_id)['categoryIds']
+
+        template_category_ids = self.templates.get_template(org_id=test_org, template_id=self.template_id)['categoryIds']
         self.assertListEqual(list(all_categories.values()), template_category_ids)
 
     def test_category_with_existing_category(self):
         categories = ['python sdk test']
-        self.templates.category(test_org, self.template_id, self.template_name, self.version, categories)
+        self.templates.category(
+            org_id=test_org,
+            template_id=self.template_id,
+            template_name=self.template_name,
+            version=self.version,
+            categories=categories
+        )
 
         new_categories = ['python sdk test', 'antoher category']
-        self.templates.category(test_org, self.template_id, self.template_name, self.version, new_categories)
+        self.templates.category(
+            org_id=test_org,
+            template_id=self.template_id,
+            template_name=self.template_name,
+            version=self.version,
+            categories=new_categories
+        )
 
-        all_categories = self.templates.list_all_categories(test_org)
+        all_categories = self.templates.list_all_categories(org_id=test_org)
         self.assertListEqual(list(all_categories.keys()), new_categories)
-        
-        template_category_ids  =  self.templates.get_template(test_org, self.template_id)['categoryIds']
-        self.assertListEqual(list(all_categories.values()), template_category_ids)
-        
 
-    
\ No newline at end of file
+        template_category_ids = self.templates.get_template(
+            org_id=test_org,
+            template_id=self.template_id
+        )['categoryIds']
+        self.assertListEqual(list(all_categories.values()), template_category_ids)
