@@ -55,6 +55,8 @@ class Graph(ApiRequestManager):
 
         self.graph_query_url = self.graph_url + "/{}/query"
 
+        self.export_query_url = self.graph_url + "/{}/query/export"
+
     @single_org
     def get_graphs_list(self, org_id=None):
         """
@@ -108,3 +110,30 @@ class Graph(ApiRequestManager):
             return result.content
 
         raise Exception(repr(result.content))
+
+    @single_org
+    def export_query(self, org_id=None, *, graph, query, nodes_dataset_name, edges_dataset_name):
+        """
+        Export a given cypher query into 2 datasets
+
+        :param org_id: Organization id where the graph is stored
+        :param graph: Graph id to be queried
+        :param query: Cypher query
+        :return:
+        """
+
+        header = self.build_header(
+            org_id=org_id,
+            others=self.content_octet
+        )
+
+        final_url = self.export_query_url.format(graph)
+
+        data = (["nodesDatasetName", nodes_dataset_name], ["edgesDatasetName", edges_dataset_name])
+
+        result = self.session.post(final_url, headers=header, data=query, params=data)
+
+        if result.status_code in [200, 201, 202]:
+            return result.content
+
+        raise Exception(json.loads(result.content))
